"""
readmetester.__main__
=====================
"""
from readmetester import main

if __name__ == "__main__":
    main()
